@@ -4,5 +4,7 @@ test_that("warnings are forwarded", {
   if(maxima.version() < "5.43")
     skip(paste("No warnings to be tested under Maxima", maxima.version(), "\n"))
 
-  expect_warning(maxima.get("load(\"abs_integrate\")$"))
+  maxima.get("float2bf: false$")
+  maxima.get("x: float(%pi)$")
+  expect_warning(maxima.get("bfloat(x);"))
 })
